%define anolis_release 1
%bcond_with xmlrpc

Name:		certmonger
Version:	0.79.18
Release:	%{anolis_release}%{?dist}
Summary:	Certificate status monitor and PKI enrollment client

License:	GPL-3.0-or-later
URL:		https://pagure.io/certmonger/
Source0:	https://pagure.io/certmonger/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	gcc
BuildRequires:	openldap-devel
BuildRequires:	krb5-devel
BuildRequires:	libidn2-devel
BuildRequires:	dbus-devel, nspr-devel, nss-devel, openssl-devel
BuildRequires:	libuuid-devel
BuildRequires:	libtalloc-devel, libtevent-devel
BuildRequires:	libcurl-devel
BuildRequires:	libxml2-devel
BuildRequires:  pkgconfig(systemd)
BuildRequires:  systemd-rpm-macros
%if %{with xmlrpc}
BuildRequires:  xmlrpc-c-devel
%endif
BuildRequires:  jansson-devel
# Required for 'make check':
#  for diff and cmp
BuildRequires:	diffutils
#  for expect
BuildRequires:	expect
#  for certutil and pk12util
BuildRequires:	nss-tools
#  for openssl
BuildRequires:	openssl
#  for dbus-launch
BuildRequires:	/usr/bin/dbus-launch
#  for dos2unix
BuildRequires:	/usr/bin/dos2unix
BuildRequires:	/usr/bin/unix2dos
#  for which
BuildRequires:	/usr/bin/which
#  for dbus tests
BuildRequires:	python3-dbus
BuildRequires:	popt-devel

# we need a running system bus
Requires:	dbus
Requires(post):	%{_bindir}/dbus-send

%{?systemd_requires}

%description
Certmonger is a service which is primarily concerned with getting your
system enrolled with a certificate authority (CA) and keeping it enrolled.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
autoreconf -i -f
%configure \
	--enable-systemd \
	--enable-tmpfiles \
	--with-homedir=%{_rundir}/certmonger \
%if %{with xmlrpc}
    --with-xmlrpc \
%endif
	--disable-dsa \
	--with-tmpdir=%{_rundir}/certmonger --enable-pie --enable-now
%if %{with xmlrpc}
%make_build XMLRPC_LIBS="-lxmlrpc_client -lxmlrpc_util -lxmlrpc"
%else
%make_build
%endif

%install
%make_install
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/certmonger/{cas,requests}
install -m755 -d $RPM_BUILD_ROOT%{_rundir}/certmonger
%{find_lang} %{name}

%generate_compatibility_deps

%check
%make_build check

%post
if test $1 -eq 1 ; then
	%{_bindir}/dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig 2>&1 || :
fi
%if %{without xmlrpc}
# remove any existing certmaster CA configuration
if test $1 -gt 1 ; then
    %{_bindir}/getcert remove-ca -c certmaster 2>&1 || :
fi
%endif
%systemd_post certmonger.service

%postun
%systemd_postun_with_restart certmonger.service

%preun
%systemd_preun certmonger.service

%files -f %{name}.lang
%license LICENSE
%dir %{abidir}
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/*
%{_datadir}/dbus-1/services/*
%dir %{_sysconfdir}/certmonger
%config(noreplace) %{_sysconfdir}/certmonger/certmonger.conf
%dir %{_rundir}/certmonger
%{_bindir}/*
%{_sbindir}/certmonger
%{_mandir}/man*/*
%{_libexecdir}/%{name}
%{_localstatedir}/lib/certmonger
%attr(0644,root,root) %config(noreplace) %{_tmpfilesdir}/certmonger.conf
%{_unitdir}/*
%{_datadir}/dbus-1/system-services/*

%files doc
%doc README.md STATUS doc/*.txt

%changelog
* Fri Apr 07 2023 Funda Wang <fundawang@yeah.net> - 0.79.18-1
- Import package for anolis 23
